<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of Pagination, a plugin for DotClear.
# Copyright (c) 2004-2007 Pep and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
/**
 @class pagenavigator

 @param	integer	idx
 @param	integer	page
 @param	integer	page_size
 @param	integer	nb_pages
 @param	string	url
 @param	boolean	search
 @param integer	groupsize
 @param	integer	nb_group
 @param integer	idx_group
 @param	integer	idx_group_start
 @param integer	idx_group_end
 */
class pagenavigator {
	var $idx       = 0;
	var $page      = 1;
	var $pagesize  = 10;
	var $nb_pages  = 1;
	var $url       = '';
	var $search    = false;

	// Nouvelles proprits pour la prise en charge des groupes de pages
	// Modifications directement inspires de la classe DC class.multipage.php
	// (Pagination 0.1.4+)
	var $groupsize = 5;
	var $nb_group  = 1;
	var $idx_group = 0;
	var $idx_group_start = 0;
	var $idx_group_end   = 0;

	/**
	 @function init

	 Prparation de l'instance

	 @param	integer	nb_items
	 @param	string	base_url
	 @param	integer	pagesize
	 @param	integer	groupsize
	 */

	function init($nb_items, $base_url, $pagesize = 0, $groupsize = 0, $search = false)
	{
		global $lang;

		if ((integer)$pagesize < 1) {
			$this->pagesize = dc_nb_post_per_page;
		} else {
			$this->pagesize = $pagesize;
		}

		if ((integer)$groupsize < 1) {
			$this->groupsize = 5;
		} else {
			$this->groupsize = $groupsize;
		}

		$this->nb_pages = ceil((integer)$nb_items / $this->pagesize);

		if (!empty($GLOBALS['pagination_current'])) {
			$this->page = (integer)$GLOBALS['pagination_current'];
			if ($this->page > $this->nb_pages || $this->page < 1) {
				$this->page = 1;
			}
			$this->idx = ($this->page - 1) * $this->pagesize;
		}

		// Nombre de groupes de page
		$this->nb_groups = (integer) ceil($this->nb_pages / $this->groupsize);

		// Index du groupe en cours
		$this->idx_group = (integer) ceil($this->page / $this->groupsize);

		// Index de la premire page du groupe courant
		$this->idx_group_start = ($this->idx_group -1 ) * $this->groupsize + 1;
		
		// Index de la dernire page du groupe courant
		$this->idx_group_end = $this->idx_group_start + $this->groupsize - 1;
		if ($this->idx_group_end > $this->nb_pages) {
			$this->idx_group_end = $this->nb_pages;
		}

		$this->search = $search;

		if (!empty($lang)) {
			$base_url = (!empty($base_url))?$lang.'/'.$base_url:$lang;
		}
		if (dc_url_scan == 'path_info') {
			$this->url = dc_blog_url.$base_url;
		} else {
			$this->url = dc_blog_url.'?'.$base_url;
		}
		if (!empty($base_url)) {
			$this->url .= '/';
		}

	}

	/**
	 @function getNavigation

	 @param	string	bloc
	 @param	string	current
	 @param	string	page_link
	 @param	string	prev_link
	 @param	string	next_link
	 @param	string	prev_group
	 @param	string	next_group
	 @param	string	sep

	 @return	string
	 */
	function getNavigation()
	{
		$args = func_get_args();
		
		// Default
		$bloc 		= '<p class="pagenav">%s</p>';
		$current 		= '<strong>%s</strong>';
		$page_link 	= '<a href="%s">%s</a>';
		$prev_link 	= '<a href="%s">&lt;&lt;</a>';
		$next_link 	= '<a href="%s">&gt;&gt;</a>';
		$prev_group 	= '<a href="%s">&hellip;</a>';
		$next_group 	= '<a href="%s">&hellip;</a>';
		$sep       	= '&nbsp;';
		
		if (!empty($args)) {
			if (is_array($args[0])) 
			{
				$options = array(
					'bloc',
					'current',
					'page_link',
					'prev_link',
					'next_link',
					'prev_group',
					'next_group',
					'sep'
				);	
				foreach ($options as $option) {
					if (!empty($args[0][$option])) {
						$$option = $args[0][$option];
					}
				}
			}
			else
			{
				$bloc 		= (!empty($args[0]))?$args[0]:$bloc;
				$current 		= (!empty($args[1]))?$args[1]:$current;
				$page_link 	= (!empty($args[2]))?$args[2]:$page_link;
				$prev_link 	= (!empty($args[3]))?$args[3]:$prev_link;
				$next_link 	= (!empty($args[4]))?$args[4]:$next_link;
				$prev_group 	= (!empty($args[5]))?$args[5]:$prev_group;
				$next_group 	= (!empty($args[6]))?$args[6]:$next_group;
				$sep       	= (!empty($args[7]))?$args[7]:$sep;
			}
		}
		
		$page_nav_str = '';

		if ($this->nb_pages > 1) {
			if ($this->search) {
				$url = $this->url.
				((substr($this->url,-1,1) == '?')?'':'?').
				'q='.$_GET['q'].'&amp;page=';
			} else {
				$url = $this->url.'p';
			}

			// Page prcdente
			if ($this->page > 1) {
				$prev = $this->page - 1;
				$page_nav_str .= sprintf($prev_link,$url.$prev);
				$page_nav_str .= $sep;
			}

			// Groupe prcdent
			if($this->idx_group > 1) {
				$i = $this->idx_group_start - $this->groupsize;
				$page_nav_str .= sprintf($prev_group,$url.$i,$i);
				$page_nav_str .= $sep;
			}

			// Groupe et pages en cours
			for ($i = $this->idx_group_start; $i <= $this->idx_group_end; $i++) {
				if ($i == $this->page) {
					$page_nav_str .= sprintf($current,$i);
				} else {
					$page_nav_str .= sprintf($page_link,$url.$i,$i);
				}
				$page_nav_str .= $sep;
			}

			// Groupe suivant
			if($this->idx_group < $this->nb_groups) {
				$i = $this->idx_group_end + 1;
				$page_nav_str .= sprintf($next_group,$url.$i,$i);
				$page_nav_str .= $sep;
			}

			// Page suivante
			if ($this->page < $this->nb_pages) {
				$next = $this->page + 1;
				$page_nav_str .= sprintf($next_link,$url.$next);
			}
		}

		return(sprintf($bloc,$page_nav_str));
	}


	/**
	 @function getCleanNavigation

	 Affiche une barre de navigation allge, idale pour les longues
	 listes de billets. Les blogueurs prolixes devraient tre ravis.

	 ( Dites "Merci, Beubeu !" Merci Beubeu ;-) )

	 @param	string	prev	Chaine pour le nom du lien page prcdente
	 @param	string	current	Chaine de formatage pour les informations de page courante
	 @param	string	next	Chaine pour le nom du lien page suivante
	 @param 	string	bloc	Chaine de formatage du bloc XHTML englobant
	 @param	string	sep		Chaine de sparation entre les lments de navigation
	 */
	function getCleanNavigation()
	{
		$args = func_get_args();
		
		// Default
		$prev 	= 'Page prcdente';
		$current 	= 'Page %1$d sur %2$d';
		$next 	= 'Page suivante';
		$bloc 	= '<p class="pagenav">%s</p>';
		$sep 	= ' - ';
		
		if (!empty($args)) {
			if (is_array($args[0])) 
			{
				$options = array(
					'prev',
					'current',
					'next',
					'bloc',
					'sep'
				);	
				foreach ($options as $option) {
					if (!empty($args[0][$option])) {
						$$option = $args[0][$option];
					}
				}
			}
			else
			{
				$prev 	= (!empty($args[0]))?$args[0]:$prev;
				$current 	= (!empty($args[1]))?$args[1]:$current;
				$next 	= (!empty($args[2]))?$args[2]:$next;
				$bloc 	= (!empty($args[3]))?$args[3]:$bloc;
				$sep 	= (!empty($args[4]))?$args[4]:$sep;
			}
		}

		$t = array();

		if ($this->nb_pages > 1) {
			if ($this->search) {
				$url = $this->url.'?q='.$_GET['q'].'&amp;page=';
			} else {
				$url = $this->url.'p';
			}

			if ( $this->page > 1 ) {
				$t[] = '<a href="'.$url.($this->page - 1).'">'.$prev.'</a>';
			}
			if ( strlen($current) > 0 ) {
				$t[] = sprintf($current,$this->page,$this->nb_pages);
			}
			if ( $this->page < $this->nb_pages ) {
				$t[] = '<a href="'.$url.($this->page + 1).'">'.$next.'</a>';
			}
		}

		return(sprintf($bloc,implode($sep,$t)));
	}


	/**
	 @function getLimitString

	 @return	string
	 */
	function getLimitString()
	{
		if ($this->page == 1) {
			return('0,'.$this->pagesize);
		} else {
			return(($this->page - 1)*$this->pagesize.','.$this->pagesize);
		}
	}
}
?>